<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>هناك حياة خارج المتصفح!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>النسخة %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>مرخّص لـ: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 هو برنامج مجاني و لكن برمجته تستهلك وقتا ثمينا.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>‎الرجاء &lt;a href=&apos;%1&apos;&gt;التبرع&lt;/a&gt; لمتابعة تطوير  %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>ترجم %1 إلى لغتك الأم بإستعمال %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>بدعم من %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>صمم الايقونة %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>نشر هذا البرنامج تحت رخصة  &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;اقفل</translation>
    </message>
    <message>
        <source>About</source>
        <translation>عن البرنامج</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>أدخل تفاصيل الرخصة الخاصة بك</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;البريد الألكتروني:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>الرقم ال&amp;خاصّ:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>الرجاء قم بترخيص %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>تسمح لك النسخة الكاملة بمشاهدة مقاطع الفيديو دون مقاطعة.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>بشرائك النسخة الكاملة، سوف تقوم أيضا بدعم العمل الشاق الذي قمت به في إنشاء %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>استخدم النسخة التجريبية</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>أدخل رخصة</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>قم بشراء رخصة</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>تحميل</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>بواسطة %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>You have %n new video(s)</numerusform><numerusform>You have %n new video(s)</numerusform><numerusform>You have %n new video(s)</numerusform><numerusform>You have %n new video(s)</numerusform><numerusform>You have %n new video(s)</numerusform><numerusform>لديك %n فيديو جديد</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>جميع الفيديوهات</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>فيديوهات لم تتم مشاهدتها</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>آخر تحديث</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>آخر إضافة</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>آخر عرض</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>الأكثر مشاهدة</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>ترتيب بـ</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>علّمها كمُشاهدة</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>أظهر التّحديثات</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>لا يوجد لديك اشتراكات. استخدم رمز النجمة للإشتراك في القنوات.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>جميع الفيديوهات</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>فيديوهات لم تتم مشاهدتها</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>علّمها كمُشاهدة</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>ألغِ الاشتراك</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>لا يوجد تحديثات لقوائم اشتراكاتك حاليًا</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>الآن</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n يوم مضى</numerusform><numerusform>%n يوم مضى</numerusform><numerusform>%n يوم مضى</numerusform><numerusform>%n يوم مضى</numerusform><numerusform>%n يوم مضى</numerusform><numerusform>%n يوم مضى</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n شهر مضى</numerusform><numerusform>%n شهر مضى</numerusform><numerusform>%n شهر مضى</numerusform><numerusform>%n شهر مضى</numerusform><numerusform>%n شهر مضى</numerusform><numerusform>%n شهر مضى</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 مشاهدة</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n اسبوع مضى</numerusform><numerusform>%n اسبوع مضى</numerusform><numerusform>%n اسبوع مضى</numerusform><numerusform>%n اسبوع مضى</numerusform><numerusform>%n اسبوع مضى</numerusform><numerusform>%n اسبوع مضى</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n سنة مضت</numerusform><numerusform>%n سنة مضت</numerusform><numerusform>%n سنة مضت</numerusform><numerusform>%n سنة مضت</numerusform><numerusform>%n سنة مضت</numerusform><numerusform>%n سنة مضت</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>بايت</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>كب</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>مب</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>بايت/ثا</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>كب/ثا</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>مب/ثا</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>ثانية</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>دقيقة</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 متبقي</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 حمل في %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>انتهي التحميل</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n تحميل</numerusform><numerusform>%n تحميل</numerusform><numerusform>%n تحميل</numerusform><numerusform>%n تحميل</numerusform><numerusform>%n تحميل</numerusform><numerusform>%n تحميل</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>تغيير الموقع...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>اختر موقع التحميل</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>موقع التحميل تغير.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>التحميل سيتم في الموقع السابق.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>التحميل الى:%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>التحميلات</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>إعادة التثبيت</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبث</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>شغّل/ألبث</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقف</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>ايقاف تشغيل المقطع الحالي</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>المقطع التالي</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>المقطع السابق</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>رفع الصوت</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>خفض الصوت</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>امام</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>خلف</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>جِد مقاطع فيديو وقنواتٍ بحسب الكلمة الرئيسة</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>أستعراض</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>تصفح الفيديوهات حسب الفئة</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>الإشتراكات</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>اشتراكات القنوات</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>اجعل نفسك مرتاحا</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;نافذة</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;تصغير الى شريط المهام</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;قف</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>وقف التشغيل و العودة لوضع البحث</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>ال&amp;سابق</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>العودة إلى المجاز السابق</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;القفز</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>القفز للفيديو التالي</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;التشغيل</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>اكمال التشغيل</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;شاشة كاملة</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>تشغيل شاشة كاملة</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;الواجهة الخفيفة</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>اخفاء القائمة و شريط المهام</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>أفتح صفحة الفيديو على &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>اذهب الى صفحة فيديو YouTube و وقف التشغيل</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>انسخ رابط الفيديو &amp;Link</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>نسخ رابط YouTube الى clipboard</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>انسخ الفيديو وعنوانه</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>نسخ رابط الفيديو الى clipboard</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>أبحث عن &amp;أجزاء الفيديو الأُخرى</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>اوجد أجزاء الفيديو الأخرى املا أن تكون في الترتيب الصحيح</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;إزالة</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>إزالة الفيديو من القائمة</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>الرفع الى &amp;اعلى</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>رفع المقاطع المختارة الى فوق في القائمة</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>الانزال الى &amp;تحت</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>انزال المقاطع المختارة الى تحت في القائمة</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;مسح تاريخ البحث </translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>مسح تاريخ البحث. لا يمكن استعادته.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;الانتهاء</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>مع السلامة</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;الموقع</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 على الشبكة</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>القيام بتبرع</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>‎الرجاء التبرع لمتابعة تطوير  %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;عن البرنامج</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>معلومات عن %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>كتم الصوت</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;تشغيل الفيديوهات يدويا</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>بدء تشغيل الفيديو يدويا</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;التحميلات</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>عرض تفاصيل عن تحميلات الفيديو</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;التحميلات</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>تحميل الفيديو الحالي</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>التقط &amp;صورة</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>ا&amp;شترك بالقناة</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>شارك الفيديو الحالي باستخدام %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;البريد الإلكتروني</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>البريد الإلكتروني</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;اقفل</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;اطفو علي القمة</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;أوقف العرض التلقائي بعد الفيديو الحالي </translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;أبلغ عن مشكلة</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;خيارات البحث...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>المزيد...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>مقاطع ذات &amp;صلة</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>شاهد مقاطع فيديو ذات صلة بهذا</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>افتح &amp;ضمن المُستعرض...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation>قائمة</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>أت&amp;حبّ %1؟ قيّمه!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>اشترِ %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;البرنامج</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;قراءة</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;القائمة</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;الفيديو</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;شارك</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;مشاهدة</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;المساعدة</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>اضغط %1 لرفع الصوت و %2 لخفضه</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>اختر موقع محتوياتك</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>جاري فتح %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>هل تريد الخروج %1  رغم وجود تحميل?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>عند اغلاق %1 التحميل سيلغى.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>الاغلاق و الغاء التحميل</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>انتظار انتهاء التحميل</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>خطأ: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;ايقاف مؤقت</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>ايقاف التشغيل</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;تحميل...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>غادر &amp;الشاشة الكاملة</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>الوقت المتبقي: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>%1%الصوت عند </translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>الصوت مكتوم</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>الصوت غير مكتوم</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>الوضوح الاقصى %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>خصوصيتك امنة</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>التحميل انتهى</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>يمكنك لصق رابط YouTube في برنامج اخر</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>يمكنك لصق رابط الفيديو في برنامج اخر</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>الرابط سيكون صالحا لمدة محدودة.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>جاري تحميل %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>من</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>جزء</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>حلقة</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>أرسلت من %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>إلغاء الاشتراك من %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>اشترك في %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>تم إلغاء متابعتك ل %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>تمت اضافة متابعة ل %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>يتوقّر إصدار جديد من %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>1% %2 متوفر الآن. لديك 3%.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>أتريد تنزيله الآن؟</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>تجاوز هذا الإصدار</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>ذكرني لاحقا</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>تثبيت التحديث</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>لصق</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>1% من 2% (3%) — 4%</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>تهيئة</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>تم</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>ايقاف التحميل</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>اظهار في %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>فتح المجلد الرئيسي</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>اعادة التحميل</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>اظهر %1 المزيد</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>لا توجد فيديوهات</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>لا يوجد المزيد من الفيديوهات</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>ترتيب بـ</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>ذات صلة</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>التاريخ</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>عدد المشاهدات</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>التقييم</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>اي وقت</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 أيام</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 يوم</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>المدة</translation>
    </message>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>قصير</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>متوسط</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>طويل</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>أقل من 4 دقائق</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>ما بين 4 ال 20 دقيقة</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>أطول من 20 دقيقة</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>الجودة</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>إنتهي</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>هذه السنة</translation>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>تمّ</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>مرحبا بك في &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>لبدء مشاهدة أشرطة الفيديو</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation> كلمة مفتاح</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>أدخل</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>كلمات بحث سابقة</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>القنوات الأخيرة</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>الحصول على النسخة الكاملة</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;عودة</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>تقدّم إلى %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>عُد إلى %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>خيارات البحث</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>هل تقصد: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>تغيير الموقع...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>حُفظت الصورة إلى %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>تغيّر موقع الصّور المُلتقطة.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>الأكثر شهرة</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>موسيقى</translation>
    </message>
    <message>
        <source>News</source>
        <translation>الأخبار</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>الأفلام</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>الألعاب</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>يتم الآن تحميل التحديث</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation>تحميل التحديث</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>يتم الآن تحميل التحديث</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>الإصدار %1 متوفر.</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>لا يمكن الحصول على دفق الفيديو %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>الجزائر</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>الأرجنتين</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>أستراليا</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>بلجيكا</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>البرازيل</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>كندا</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>تشيلي</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>كولومبيا</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>جمهورية التشيك</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>مصر</translation>
    </message>
    <message>
        <source>France</source>
        <translation>فرنسا</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>ألمانيا</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>غانا</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>اليونان</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>هونغ كونغ</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>هنغاريا</translation>
    </message>
    <message>
        <source>India</source>
        <translation>الهند</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>إندونيسيا</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>إيرلندا</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>إسرائيل</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>إيطاليا</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>اليابان</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>الأردن</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>كينيا</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>ماليزيا</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>المكسيك</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>المغرب</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>هولندا</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>نيوزيلندا </translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>نيجيريا</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>بيرو</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>الفلبين</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>بولندا</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>روسيا</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>المملكة العربية السعودية</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>سنغافورة</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>جنوب أفريقيا</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>كوريا الجنوبية</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>إسبانيا</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>السويد</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>تايوان</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>تونس</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>تركيا</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>أوغندا</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>الإمارات العربية المتحدة</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>المملكة المتحدة</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>اليمن</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>العالم</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>لا يمكن الحصول على دفق الفيديو %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>يتوقّر إصدار جديد من %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>1% %2 متوفر الآن. لديك 3%.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>أتريد تنزيله الآن؟</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>ذكرني لاحقا</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>تحميل التحديث</translation>
    </message>
</context>
</TS>